@@ -9,8 +9,7 @@ from getmac import get_mac_address as gma
 def inference(img_path, lang):
     try:
         macadd=gma()
-        '''uniqueadd =["60:e3:2b:34:66:ce"]'''
-        uniqueadd=["a8:7e:ea:41:ad:34"]
+        uniqueadd =["60:e3:2b:34:66:ce"]
         if macadd in uniqueadd:
             print("Configured Sucessfully")
             ocr = PaddleOCR(use_angle_cls=True, lang=lang,use_gpu=True)
@@ -24,7 +23,7 @@ def inference(img_path, lang):
                     scores.pop(i)
                     txts.pop(i)
             if len(txts)==0:          #no object detected
-                return "Object Not Found",float(0.0)
+                return "-1",float(0.0)  #object not found
             try:                          # most repeating txts
                 txts=[mode(txts)]
                 scores=[max(scores)]
@@ -37,14 +36,14 @@ def inference(img_path, lang):
             for i in txts:  
                 try:                  # if txts >20
                     if float(i)>=20.0:
-                        return "Could Not Process",float(0.0)
+                        return "-2",float(0.0) #could not process
                 except:
                     pass
             return str(txts[0]),float(scores[0])
         else:
-            return "Could Not Configured",float(0.0)
+            return "-3",float(0.0)  #could not configured
     except:
-        return "Could Not Process,Exception",float(0.0)
+        return "-4",float(0.0) # could not process,Exception
     
 
 '''if __name__ == "__main__":
